Class: FastlaneCore::ShellScriptTransporterExecutor

Inherits:
TransporterExecutor show all
Defined in:
lib/fastlane_core/itunes_transporter.rb

Overview

Generates commands and executes the iTMSTransporter through the shell script it provides by the same name

Instance Method Summary collapse

Methods inherited from TransporterExecutor

#execute

Instance Method Details

#build_download_command(username, password, apple_id, destination = "/tmp") ⇒ Object



149
150
151
152
153
154
155
156
157
158
# File 'lib/fastlane_core/itunes_transporter.rb', line 149

def build_download_command(username, password, apple_id, destination = "/tmp")
  [
    '"' + Helper.transporter_path + '"',
    "-m lookupMetadata",
    "-u \"#{username}\"",
    "-p #{shell_escaped_password(password)}",
    "-apple_id #{apple_id}",
    "-destination '#{destination}'"
  ].join(' ')
end

#build_upload_command(username, password, source = "/tmp") ⇒ Object



136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/fastlane_core/itunes_transporter.rb', line 136

def build_upload_command(username, password, source = "/tmp")
  [
    '"' + Helper.transporter_path + '"',
    "-m upload",
    "-u \"#{username}\"",
    "-p #{shell_escaped_password(password)}",
    "-f '#{source}'",
    ENV["DELIVER_ITMSTRANSPORTER_ADDITIONAL_UPLOAD_PARAMETERS"], # that's here, because the user might overwrite the -t option
    "-t 'Signiant'",
    "-k 100000"
  ].join(' ')
end

#handle_error(password) ⇒ Object



160
161
162
163
164
165
166
167
168
169
170
# File 'lib/fastlane_core/itunes_transporter.rb', line 160

def handle_error(password)
  # rubocop:disable Style/CaseEquality
  unless /^[0-9a-zA-Z\.\$\_]*$/ === password
    UI.error([
      "Password contains special characters, which may not be handled properly by iTMSTransporter.",
      "If you experience problems uploading to iTunes Connect, please consider changing your password to something with only alphanumeric characters."
    ].join(' '))
  end
  # rubocop:enable Style/CaseEquality
  UI.error("Could not download/upload from iTunes Connect! It's probably related to your password or your internet connection.")
end